package nova.traffic.been;

import nova.traffic.utils.LogUtil;
import nova.traffic.utils.NovaUtils;

import java.nio.charset.StandardCharsets;

public class SocketResult {
    private static final byte SUCCESS = 1;

    private byte[] parseBuffer;

    /**
     * 解析后的buffer数据
     * @return
     */
    public byte[] getParseBuffer() {
        return parseBuffer;
    }

    public SocketResult(byte[] buffer) {
        parseBuffer=  parseBuffer(buffer);
    }

    /**
     * @return 获取解析后的data数据
     */
    public byte[] parseBuffer(byte[] buffer) {
        byte[] parseBuffer = null;
        try {
            if (buffer.length > 0) {
                if (buffer[0] == (NovaUtils.WHAT_EXPAND_PARAM_MARK )) {
                    //新协议
                    parseBuffer = new byte[buffer.length - 3];
                    System.arraycopy(buffer, 3, parseBuffer, 0, parseBuffer.length);
                } else {
                    parseBuffer = new byte[buffer.length - 1];
                    System.arraycopy(buffer, 1, parseBuffer, 0, parseBuffer.length);
                }
            }
        } catch (Exception e) {
            LogUtil.log("协议解析异常：" + e.toString());
        }
        return parseBuffer;
    }

    /**
     * 获取String内容
     *
     * @return
     */
    public String getResult() {
        return getResult(true);
    }

    private String getResult(boolean isMark) {
        if (parseBuffer != null) {
            if (isMark) {
                return parseBuffer[0] == SUCCESS ? new String(parseBuffer, 1, parseBuffer.length - 1, StandardCharsets.UTF_8) : null;
            } else {
                return new String(parseBuffer, StandardCharsets.UTF_8);
            }
        }

        return null;
    }

    /**
     * 获取状态值
     *
     * @return
     */
    public int getCode() {
        try {
            if (parseBuffer == null) {
                return NovaUtils.SEND_NOT_RECV_ERROR;
            } else if (parseBuffer.length >= 1 && parseBuffer[0] != SUCCESS) {
                return NovaUtils.SEND_RECV_ERROR;
            }
            return SUCCESS;
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
            return NovaUtils.IO_ERROR;
        }

    }
    /**
     * 获取值
     *
     * @return
     */
    public int getValue() {
        try {
            if (parseBuffer == null) {
                return NovaUtils.SEND_NOT_RECV_ERROR;
            }
            if (parseBuffer.length >= 1) {
                return parseBuffer[0];
            }else {
                return NovaUtils.PARAM_ERROR;
            }
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
            return NovaUtils.IO_ERROR;
        }

    }


}
