package nova.traffic.fileserver;

import nova.traffic.utils.LogUtil;
import nova.traffic.utils.NovaUtils;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.lang.ref.WeakReference;
import java.net.Socket;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;

public class FileClient {
	private Socket socket;
	private final static int TAG_LENGTH = 50;
	private HashMap<String,String> taskMap;
	private WeakReference<Callback>  weakReference;
	public FileClient(Socket socket, HashMap<String,String> taskMap,Callback  callback) {
		this.socket=socket;
		this.taskMap=taskMap;
		this.weakReference=new WeakReference<Callback>(callback);
	}
	public void recive() {
		try {
			if(socket != null) {
				new Thread(new Runnable() {
					public void run() {
						if(socket == null) {
							return;
						}
						InputStream inputStream = null;
						FileOutputStream fileOutputStream = null;
						try {
							inputStream = socket.getInputStream();
							String tag = checkTag(inputStream);
							if(null == tag) {
								LogUtil.log("tag 错误");
								return;
							}
							int fileLenght = getFileLenght(inputStream);
							if(fileLenght<=0) {
								LogUtil.log("文件长度错误");
								return;
							}
							byte [] b = new byte[1024];
							int i = 0;
							if(taskMap == null) {
								return;
							}
							String filePath = taskMap.get(tag);
							if(filePath == null || filePath.isEmpty()) {
								return;
							}
							File file = new File(filePath);
							fileOutputStream = new FileOutputStream(file);
							while ((i = inputStream.read(b))>0) {
								fileLenght-=i;
								fileOutputStream.write(b,0,i);
								if(fileLenght<=0) {
									break;
								}
							}
							fileOutputStream.flush();
							LogUtil.log("文件写入完毕");
							if(weakReference != null && weakReference.get() != null) {
								synchronized (weakReference) {
									weakReference.get().onReceive(tag, filePath);
								}
							}
						} catch (Exception e) {
							e.printStackTrace();
						} finally {
							try {
								if(null != inputStream) {
									inputStream.close();
								}
							} catch (IOException e1) {
								// TODO Auto-generated catch block
								e1.printStackTrace();
							}
							try {
								if(fileOutputStream != null) {
									fileOutputStream.close();
								}
							} catch (IOException e1) {
								// TODO Auto-generated catch block
								e1.printStackTrace();
							}
							try {
								if(null != socket) {
									socket.close();
								}
							} catch (IOException e) {
								e.printStackTrace();
							}
						}
					}
				}).start();
			}
		}catch (Exception e) {
			// TODO: handle exception
			e.printStackTrace();
		}
	}

	private int getFileLenght(InputStream inputStream) throws IOException {
		byte[] l = new byte[4];
		int i = inputStream.read(l);
		if(i==4) {
			return NovaUtils.bytesToInt(l, 0);
		}
		return 0;
	}

	private String checkTag(InputStream inputStream) throws IOException {
		if(taskMap == null) {
			return null;
		}
		synchronized (taskMap) {
			byte [] tagByte = new byte[TAG_LENGTH];
			int i = inputStream.read(tagByte);
			if(i != TAG_LENGTH) {
				return null;
			}
			int tagL = tagByte[0];
			byte[] tag = new byte[tagL];
			System.arraycopy(tagByte, 1, tag, 0, tagL);
			String tagStr = new String(tag,StandardCharsets.UTF_8);
			if(taskMap.keySet().contains(tagStr)) {
				return tagStr;
			};
			return null;
		}
	}
}
