package nova.traffic.fileserver;

import nova.traffic.utils.LogUtil;

import java.lang.ref.WeakReference;
import java.util.HashMap;
import java.util.UUID;

public class FileServer implements Callback {
    private static FileServer instance;
    private String ip;
    private int port;
    private FileServerSocket serverSocket;
    private HashMap<String, WeakReference<Callback>> callbacks;

    public synchronized static FileServer getInstance() {
        if (instance == null) {
            instance = new FileServer();
        }
        return instance;
    }

    public void init(String ip, int port) {
        this.ip = ip;
        this.port = port;
    }

    public boolean isInit() {
        return ip != null && port != 0;
    }


    public String getIp() {
        return ip;
    }

    public int getPort() {
        return port;
    }

    public synchronized String receiveFile(String savePath) {
        if (checkSocket()) {
            String uuid = UUID.randomUUID().toString();
            serverSocket.addTask(uuid, savePath);
            return uuid;
        }
        return null;
    }

    private synchronized boolean checkSocket() {
        if (serverSocket == null) {
            serverSocket = new FileServerSocket(this);
            return serverSocket.start(port);
        }
        return true;
    }

    public synchronized String sendFile() {
        return null;
    }

    public synchronized void addCallback(String tag, Callback callback) {
        if (null == callbacks) {
            callbacks = new HashMap<String, WeakReference<Callback>>();
        }
        synchronized (callbacks) {
            callbacks.put(tag, new WeakReference<Callback>(callback));
        }
    }

    public synchronized void removeCallback(String tag) {
        if (null != callbacks) {
            synchronized (callbacks) {
                callbacks.remove(tag);
            }
        }
    }

    @Override
    public void onReceive(String tag, String filePath) {
        if (callbacks != null) {
            synchronized (callbacks) {
                WeakReference<Callback> reference = callbacks.get(tag);
                if (reference == null) {
                    LogUtil.log(tag + "   " + filePath + "无监听");
                    return;
                }
                Callback callback = reference.get();
                if (callback == null) {
                    LogUtil.log(tag + "   " + filePath + "无监听");
                    return;
                }
                synchronized (callback) {
                    callback.onReceive(tag, filePath);
                }
            }
        }

    }
}
