package nova.traffic.fileserver;

import nova.traffic.utils.LogUtil;

import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.HashMap;

public class FileServerSocket implements Callback {
    private ServerSocket serverSocket;
    private HashMap<String, String> taskMap;
    private Callback callback;
    private static final int TIME_OUT = 60 * 1000;

    FileServerSocket(Callback callback) {
        this.callback = callback;
    }

    public boolean start(int port) {
        try {
            serverSocket = new ServerSocket(port);
            new Thread(() -> {
                while (true) {
                    Socket socket = null;
                    try {
                        socket = serverSocket.accept();
                        socket.setKeepAlive(true);
                        socket.setSoTimeout(TIME_OUT);
                        new FileClient(socket, new HashMap(taskMap), FileServerSocket.this).recive();
                    } catch (IOException e1) {
                        LogUtil.log(e1.toString());
                        break;
                    }
                }
            }).start();
        } catch (IOException e) {
            LogUtil.log(e.toString());
            return false;
        }
        return true;
    }

    public synchronized void addTask(String uuid, String savePath) {
        if (taskMap == null) {
            taskMap=new HashMap<>();
        } else {
            if (taskMap.size() > 1000) {
                //防止异常数据导致内存溢出
                synchronized (taskMap) {
                    taskMap.clear();
                }
            }
        }
        synchronized (taskMap) {
            taskMap.put(uuid, savePath);
        }
    }

    @Override
    public void onReceive(String tag, String filePath) {
        if (taskMap != null) {
            synchronized (taskMap) {
                if (taskMap.keySet().contains(tag)&&callback != null) {
                        synchronized (callback) {
                            callback.onReceive(tag, filePath);
                        }
                }
                taskMap.remove(tag);
            }
        }

    }
}
