package nova.traffic.media;


import java.util.ArrayList;
import java.util.List;

/**
 * 基础底图 信息
 */
public class BaseRoute {
    private String name; //道路名称
    private int id; //id编号
    private String color; //路径默认颜色
    private List<RoadPoint> points; //道路集合点
    private int width; //画笔宽度


    public BaseRoute(BaseRouteBuild build) {
        this.id = build.id;
        this.name = build.name;
        this.points = build.points;
        this.width = build.width;
        this.color = build.color;

    }

    public final static class BaseRouteBuild {
        private int id; //id编号
        private String name; //道路名称
        private String color; //路径默认颜色
        private List<RoadPoint> points; //道路集合点
        private int width; //画笔宽度

        public BaseRouteBuild() {
            points = new ArrayList<>();

        }

        public BaseRoute build() {
            return new BaseRoute(this);
        }

        /**
         * 道路id
         *
         * @param id
         * @return
         */
        public BaseRouteBuild Id(int id) {
            this.id = id;
            return this;
        }

        /**
         * 道路名称
         * name
         *
         * @return
         */
        public BaseRouteBuild name(String name) {
            this.name = name;
            return this;
        }

        /**
         * 拥堵路段终点
         *
         * @param x
         * @param y
         * @return
         */
        public BaseRouteBuild addPoint(int x, int y) {
            RoadPoint roadPoint = new RoadPoint(x, y);
            points.add(roadPoint);
            return this;
        }


        /**
         * 路段线宽
         *
         * @param width
         * @return
         */
        public BaseRouteBuild width(int width) {
            this.width = width;
            return this;
        }

        /**
         * 路段颜色
         *
         * @param color
         * @return
         */
        public BaseRouteBuild color(String color) {
            this.color = color;
            return this;
        }
    }


}
