package nova.traffic.media;

public final class DClockMediaBuild extends BaseMediaBuild {
    //文本
    String font = "1";
    int textSize = 1616, fontStyle = 0;
    String alignmentH = "0", alignmentV = "0";
    String lineSpace = "1";
    int wordSpace = 0;
    String textColor = "1", backGroundColor = "8";
    int playCount = 1;

    //时间信息
    String showFourYear = "1";
    String showFormat = "0"; //日期显示格式
    String showYear = "1";
    String showMonth = "1";
    String showDay = "1";
    String showHour = "1";
    String showMinute = "1";
    String showSecond = "1";
    String showWeek = "1";
    String singleLine = "1";

    String timezoneID = "Asia/Shanghai";
    String timezoneOffset = "GMT+08:00";
    String charWeek = "周日|周一|周二|周三|周四|周五|周六"; //默认不填
    String dateFormat = "$yyyy-$MM-$dd_n_$HH:$mm:$ss $E";//显示格式，标准

    @Override
    public DClockMediaBuild x(int x) {
        return (DClockMediaBuild) super.x(x);
    }

    @Override
    public DClockMediaBuild y(int y) {
        return (DClockMediaBuild) super.y(y);
    }

    @Override
    public DClockMediaBuild width(int width) {
        return (DClockMediaBuild) super.width(width);
    }

    @Override
    public DClockMediaBuild height(int height) {
        return (DClockMediaBuild) super.height(height);
    }

    /**
     * 字体类型
     *
     * @param font 【1-黑体 2-楷体 3-宋体 4-仿宋 5-隶书可以使用字体名称，如 arial 等。】
     * @return DClockMediaBuild
     */
    public DClockMediaBuild font(String font) {
        this.font = font;
        return this;
    }

    /**
     * 字体大小，单位像素。由宽度和高度组成，宽高各占两个字符。如 0808、3232，999999，对应的字体是 8、32、999。
     * 默认值 1616
     *
     * @param textSize 默认值 1616
     * @return DClockMediaBuild
     */
    public DClockMediaBuild textSize(int textSize) {
        this.textSize = textSize;
        return this;
    }

    /**
     * 字体风格
     * 0-常规
     * 1-加粗
     * 2-倾斜
     * 4-下划线
     * 8-中划线
     * 字体风格可以组合，
     * 例如 3 表示加粗且倾
     * 斜显示。
     *
     * @param fontStyle 字体风格
     * @return DClockMediaBuild
     */
    public DClockMediaBuild fontStyle(int fontStyle) {
        this.fontStyle = fontStyle;
        return this;
    }

    /**
     * 0-左对齐
     * 1-右对齐
     * 2-居中
     *
     * @param alignmentH 文本内容水平对齐方式
     * @return DClockMediaBuild
     */
    public DClockMediaBuild alignmentH(String alignmentH) {
        this.alignmentH = alignmentH;
        return this;
    }

    /**
     * 0-上对齐
     * 1-下对齐
     * 2-居中
     *
     * @param alignmentV 文本内容垂直对齐方式。
     * @return DClockMediaBuild
     */
    public DClockMediaBuild alignmentV(String alignmentV) {
        this.alignmentV = alignmentV;
        return this;
    }

    /**
     * @param lineSpace 行间距，单位像素。0-100
     * @return DClockMediaBuild
     */
    public DClockMediaBuild lineSpace(String lineSpace) {
        this.lineSpace = lineSpace;
        return this;
    }

    /**
     * @param wordSpace 字符间距，单位像素。0-100
     * @return DClockMediaBuild
     */
    public DClockMediaBuild wordSpace(int wordSpace) {
        this.wordSpace = wordSpace;
        return this;
    }

    /**
     * 1-红色
     * 2-绿色
     * 3-蓝色
     * 4-黄色
     * 5-紫色
     * 6-青色
     * 7-白色
     * 8-黑色
     * 可以使用 RGB 定义，
     *
     * @param textColor 字符显示颜色。
     * @return DClockMediaBuild
     */
    public DClockMediaBuild textColor(String textColor) {
        this.textColor = textColor;
        return this;
    }

    /**
     * @param backGroundColor 字符显示区域背景颜色 同字符设置   默认值8
     * @return DClockMediaBuild
     */
    public DClockMediaBuild backGroundColor(String backGroundColor) {
        this.backGroundColor = backGroundColor;
        return this;
    }


    /**
     * @param playCount 播放次数 默认1
     * @return DClockMediaBuild
     */
    public DClockMediaBuild playCount(int playCount) {
        this.playCount = playCount;
        return this;
    }


    /**
     * 数字时钟显示样式。
     *
     * @param singleLine 0-多行显示
     *                   1-单行显示
     * @return DClockMediaBuild
     */
    public DClockMediaBuild singleLine(String singleLine) {
        this.singleLine = singleLine;
        return this;
    }

    /**
     * @param showYear 是否显示年。
     * @return DClockMediaBuild
     */
    public DClockMediaBuild showYear(String showYear) {
        this.showYear = showYear;
        return this;
    }

    /**
     * @param showMonth 是否显示月。
     * @return DClockMediaBuild
     */
    public DClockMediaBuild showMonth(String showMonth) {
        this.showMonth = showMonth;
        return this;
    }

    /**
     * @param showDay 是否显示月
     * @return DClockMediaBuild
     */
    public DClockMediaBuild showDay(String showDay) {
        this.showDay = showDay;
        return this;
    }

    /**
     * @param showHour 是否显示时
     * @return DClockMediaBuild
     */
    public DClockMediaBuild showHour(String showHour) {
        this.showHour = showHour;
        return this;
    }

    /**
     * @param showMinute 是否显示分
     * @return DClockMediaBuild
     */
    public DClockMediaBuild showMinute(String showMinute) {
        this.showMinute = showMinute;
        return this;
    }

    /**
     * @param showSecond 是否显示秒
     * @return DClockMediaBuild
     */
    public DClockMediaBuild showSecond(String showSecond) {
        this.showSecond = showSecond;
        return this;
    }

    /**
     * @param week 是否显示周
     * @return DClockMediaBuild
     */
    public DClockMediaBuild week(String week) {
        this.showWeek = week;
        return this;
    }

    /**
     * $yyyy 年份
     * $MM 月份
     * $dd 天
     * $HH 小时
     * $mm 分
     * $ss 秒
     * $E 星期
     * $N 上午/下午
     * _n_ 换行
     * 例如：“$dd-$MM-$yyyy
     * $HH:$mm:$ss $E” 的
     * 显 示 效 果 为
     * “24-09-2020 12:10:10
     * 星期四”
     *
     * @param dateFormat 显示格式 日期、时间、星期的显示
     * @return DClockMediaBuild
     */
    public DClockMediaBuild dateFormat(String dateFormat) {
        this.dateFormat = dateFormat;
        return this;
    }

    /**
     * @param timezoneID 时区 数字时钟显示的时区 ID。
     * @return DClockMediaBuild
     */
    public DClockMediaBuild timezoneID(String timezoneID) {
        this.timezoneID = timezoneID;
        return this;
    }

    /**
     * @param timezoneOffset 数 字 时 钟 显 示 的 时 区 的
     *                       GMT 偏移。
     * @return DClockMediaBuild
     */
    public DClockMediaBuild timezoneOffset(String timezoneOffset) {
        this.timezoneOffset = timezoneOffset;
        return this;
    }

    /**
     * 0-年月日顺序
     * 1-日月年顺序
     * 2-月日年顺序
     *
     * @param showFormat 日期年、月、日显示顺序。 [可不用，直接按照dataFormat结构]
     * @return DClockMediaBuild
     */
    public DClockMediaBuild showFormat(String showFormat) {
        this.showFormat = showFormat;
        return this;
    }

    /**
     * 0-显示两位年
     * 1-显示四位年
     *
     * @param showFourYear 年显示样式
     * @return DClockMediaBuild
     */
    public DClockMediaBuild showFourYear(String showFourYear) {
        this.showFourYear = showFourYear;
        return this;
    }

    /**
     * 不填此项
     * 默认中文
     *
     * @param charWeek 一周字符 一周显示字符。使用|隔开
     * @return  DClockMediaBuild
     */
    public DClockMediaBuild setCharWeek(String charWeek) {
        this.charWeek = charWeek;
        return this;
    }

    @Override
    public BaseMedia build() {
        return new DClockMedia(this);
    }


}
