package nova.traffic.media;

import java.util.ArrayList;
import java.util.List;

/**
 * 设置策略
 * 1. 普通添加节目   2. 局部更新   3.item实时更新（待定是否要添加）
 * <p>
 * 组装播放列表
 */
public class ItemMedia {

    private List<BaseMedia> itemMedia;
    private int duration;
    private String screenIn;
    private String screenOut;
    private String screenSpeed;
    private String flashSpeed;
    private String flashCount;
    private String playCount;
    private int index;

    public ItemMedia(ItemMediaBuilder builder) {
        this.itemMedia = builder.itemMedia;
        duration = builder.duration;
        this.screenIn = builder.screenIn;
        this.screenOut = builder.screenOut;
        this.screenSpeed = builder.screenSpeed;
        this.flashSpeed = builder.flashSpeed;
        this.flashCount = builder.flashCount;
        this.playCount = builder.playCount;
        this.index=builder.index;
    }

    public int getIndex() {
        return index;
    }

    public String createProtocol() {

        String param = "param="
                + duration + ","
                + screenIn + ","
                + screenOut + ","
                + screenSpeed + ","
                + flashSpeed + ","
                + flashCount + ","
                + playCount;

        StringBuffer protocol = new StringBuffer();
        protocol.append(param).append("\n");
        itemMedia.forEach(item -> {
            protocol.append(item.setDuration(duration).createProtocol()).append("\n");
        });
        protocol.deleteCharAt(protocol.length() - 1);//删除最后一个空格
        return protocol.toString();
    }

    /**
     * 获取当前媒体文件路径
     *
     * @return 媒体文件
     */
    public List<String> getMediaFileList() {
        List<String> list = new ArrayList<>();
        itemMedia.forEach(media -> {
            if (media instanceof VideoMedia) {
                String filePath = ((VideoMedia) media).filePath;
                list.add(filePath);
            }
            if (media instanceof GifMedia) {
                String filePath = ((GifMedia) media).filePath;
                list.add(filePath);
            }
            if (media instanceof ImageMedia) {
                String filePath = ((ImageMedia) media).filePath;
                list.add(filePath);
            }
        });
        return list;

    }


}
