package nova.traffic.media;

/**
 * 交通拥堵路段
 */
public class TJRoute {
    private int id;
    //开始坐标[暂不支持]
    private RoadPoint starPoint;
    //结束坐标[暂不支持]
    private RoadPoint endPoint;
    // 开始百分比
    private Float startPercent;
    //结束百分比
    private Float endPercent;
    //画笔宽度
    private int width=1;
    //画笔颜色
    private String color;


    public TJRoute(TJRouteBuild build) {
        this.id = build.id;
        this.starPoint = build.starPoint;
        this.endPoint = build.endPoint;
        this.startPercent = build.startPercent;
        this.endPercent = build.endPercent;
        this.width = build.width;
        this.color = build.color;

    }

    public final static class TJRouteBuild {
        private int id;
        //开始坐标
        private RoadPoint starPoint;
        //结束坐标
        private RoadPoint endPoint;
        // 开始百分比
        private Float startPercent;
        //结束百分比
        private Float endPercent;
        //画笔宽度
        private int width;
        //画笔颜色
        private String color;
        //百分比模式
        public static final int MODE_PERCENTAGE = 0;
        //坐标模式
        public static final int MODE_COORDINATE = 1;
        //默认百分比模式
        public int mode = MODE_PERCENTAGE;


        public TJRoute build() {

            switch (mode) {
                case MODE_COORDINATE:
                    if (starPoint == null || endPoint == null) {
                        throw new IllegalStateException("坐标不能为空");
                    }
                    break;
                case MODE_PERCENTAGE:
                    if (startPercent == null || endPercent == null) {
                        throw new IllegalStateException("百分比不能为空");
                    }
                    break;
                default:
                    break;
            }
            return new TJRoute(this);
        }

        /**
         * 拥堵路段id
         *
         * @param id
         * @return
         */
        public TJRouteBuild Id(int id) {
            this.id = id;
            return this;
        }

        /**
         * 拥堵路段通过坐标点设置【暂不支持】
         *
         * @return
         */
        public TJRouteBuild usePoint() {
            this.mode = MODE_COORDINATE;
            return this;
        }

        /**
         * 拥堵路段通过百分比设置
         *
         * @return
         */
        public TJRouteBuild usePercent() {
            this.mode = MODE_PERCENTAGE;
            return this;
        }

        /**
         * 拥堵路段起点
         *
         * @param x
         * @param y
         * @return
         */
        public TJRouteBuild starPoint(int x, int y) {
            this.starPoint = new RoadPoint(x, y);
            return this;
        }

        /**
         * 拥堵路段终点
         *
         * @param x
         * @param y
         * @return
         */
        public TJRouteBuild endPoint(int x, int y) {
            this.endPoint = new RoadPoint(x, y);
            return this;
        }

        /**
         * 设置开始路段的百分比
         *
         * @param startPercent
         * @return
         */
        public TJRouteBuild startPercent(float startPercent) {
            this.startPercent = startPercent;
            return this;
        }

        /**
         * 设置结束路径的百分比
         *
         * @param endPercent
         * @return
         */
        public TJRouteBuild endPercent(float endPercent) {
            this.endPercent = endPercent;
            return this;
        }

        /**
         * 路段线宽
         *
         * @param width
         * @return
         */
        public TJRouteBuild width(int width) {
            this.width = width;
            return this;
        }

        /**
         * 路段颜色
         *
         * @param color
         * @return
         */
        public TJRouteBuild color(String color) {
            this.color = color;
            return this;
        }
    }


}
