package nova.traffic.media;

public final class TableMediaBuilder extends BaseMediaBuild {

    TableMedia.FormBaseInfo formInfo;
    private String backgroudColor = "8";
    private boolean isShowYSequence = false;
    private String[] ySequenceDateArray;
    private String ySequenceFontName = "1";
    private int ySequenceFontSize = 0;
    private String ySequenceFontColor = "1";
    private int ySequenceFontStyle = 0;
    private boolean isShowXSequence = false;
    private String[] xSequenceDateArray;
    private String xSequenceFontName = "1";
    private int xSequenceFontSize = 0;
    private String xSequenceFontColor = "1";
    private int xSequenceFontStyle = 0;
    private int sequenceGridWidth = 0;
    private String sequenceGridColor = "2";
    private int horizontalPadding = 0;
    private int verticalPadding = 0;
    private String animationType = "0";
    private String animationValue = "0";
    private String animationWaitValue = "0";
    private String[] backgroudColorX, colorY, backgroudColorY, colorX;
    private int[] yTableHightArray, xTableWidthArray;
    private int contentFontName = 1;
    private int contentFontSize = 0;
    private String contentFontColor = "1";
    private int contentFontStyle = 0;
    private int contentGridWidth = 0;
    private String contentGridColor = "2";

    private int[] yTableAlignArray, xTableAlignArray;
    private String[][] yxDate2DArray;
    private int[][] userCellRange;
    private String excelName;
    private int excelSheetIndex;

    //数据库相关
    private String dbType;
    private String ip;
    private int port;
    private String dbTable;
    private String user;
    private String password;
    private int cycleTime;
    private String dbSql;
    private boolean isUseDb = false; //使用数据库需要确定


    @Override
    public BaseMedia build() {
        this.formInfo = new TableMedia.FormBaseInfo();
        if (isUseDb) {
            TableMedia.DBInfo dbInfo = new TableMedia.DBInfo();
            dbInfo.dbType = dbType;
            dbInfo.ip = ip;
            dbInfo.port = port;
            dbInfo.dbTable = dbTable;
            dbInfo.user = user;
            dbInfo.password = password;
            dbInfo.cycleTime = cycleTime;
            dbInfo.dbSql = dbSql;
            formInfo.dbInfo = dbInfo;
        }
        formInfo.backgroudColor = backgroudColor;
        formInfo.isShowYSequence = isShowYSequence;
        formInfo.ySequenceDateArray = ySequenceDateArray;
        formInfo.ySequenceFontName = ySequenceFontName;
        formInfo.ySequenceFontSize = ySequenceFontSize;
        formInfo.ySequenceFontColor = ySequenceFontColor;
        formInfo.ySequenceFontStyle = ySequenceFontStyle;
        formInfo.isShowXSequence = isShowXSequence;
        formInfo.xSequenceDateArray = xSequenceDateArray;
        formInfo.xSequenceFontName = xSequenceFontName;
        formInfo.xSequenceFontSize = xSequenceFontSize;
        formInfo.xSequenceFontColor = xSequenceFontColor;
        formInfo.xSequenceFontStyle = xSequenceFontStyle;
        formInfo.sequenceGridWidth = sequenceGridWidth;
        formInfo.sequenceGridColor = sequenceGridColor;
        formInfo.horizontalPadding = horizontalPadding;
        formInfo.verticalPadding = verticalPadding;
        formInfo.animationType = animationType;
        formInfo.animationValue = animationValue;
        formInfo.animationWaitValue = animationWaitValue;
        formInfo.backgroudColorX = backgroudColorX;
        formInfo.colorY = colorY;
        formInfo.backgroudColorY = backgroudColorY;
        formInfo.colorX = colorX;
        formInfo.yTableHightArray = yTableHightArray;
        formInfo.xTableWidthArray = xTableWidthArray;
        formInfo.contentFontName = contentFontName;
        formInfo.contentFontSize = contentFontSize;
        formInfo.contentFontColor = contentFontColor;
        formInfo.contentFontStyle = contentFontStyle;
        formInfo.contentGridWidth = contentGridWidth;
        formInfo.contentGridColor = contentGridColor;
        formInfo.yTableAlignArray = yTableAlignArray;
        formInfo.xTableAlignArray = xTableAlignArray;
        formInfo.yxDate2DArray = yxDate2DArray;
        formInfo.userCellRange = userCellRange;
        formInfo.excelName = excelName;
        formInfo.excelSheetIndex = excelSheetIndex;
        return new TableMedia(this);
    }

    @Override
    public TableMediaBuilder x(int x) {
        return (TableMediaBuilder) super.x(x);
    }

    @Override
    public TableMediaBuilder y(int y) {
        return (TableMediaBuilder) super.y(y);
    }

    @Override
    public TableMediaBuilder width(int width) {
        return (TableMediaBuilder) super.width(width);
    }

    @Override
    public TableMediaBuilder height(int height) {
        return (TableMediaBuilder) super.height(height);
    }

    public TableMediaBuilder useDB(boolean useDb) {
        isUseDb = useDb;
        return this;
    }

    /**
     * 表格背景颜色。
     *
     * @param backGroundColor String
     *                        1-红色
     *                        2-绿色
     *                        3-蓝色
     *                        4-黄色
     *                        5-紫色
     *                        6-青色
     *                        7-白色
     *                        8-黑色
     *                        可 以 使 用
     *                        RGB 定义，如
     *                        FF0000 表示
     *                        红色
     * @return TableMediaBuilder
     */
    public TableMediaBuilder backGroundColor(String backGroundColor) {
        this.backgroudColor = backGroundColor;
        return this;
    }

    /**
     * 是否显示行
     * 序列。
     *
     * @param showYSequence bool  默认false
     *                      true-显示
     *                      false-不显示
     * @return TableMediaBuilder
     */
    public TableMediaBuilder isShowYSequence(boolean showYSequence) {
        isShowYSequence = showYSequence;
        return this;
    }

    /**
     * 行序列。
     *
     * @param ySequenceDateArray String[] 默认null
     * @return TableMediaBuilder
     */
    public TableMediaBuilder ySequenceDateArray(String[] ySequenceDateArray) {
        this.ySequenceDateArray = ySequenceDateArray;
        return this;
    }

    /**
     * 行序列字体。
     *
     * @param ySequenceFontName 默认1
     *                          1-黑体
     *                          2-楷体
     *                          3-宋体
     *                          4-仿宋
     *                          5-隶书
     *                          可以使用字体
     *                          名称，
     * @return TableMediaBuilder
     */
    public TableMediaBuilder ySequenceFontName(String ySequenceFontName) {
        this.ySequenceFontName = ySequenceFontName;
        return this;
    }

    /**
     * 行序列字体大小。
     *
     * @param ySequenceFontSize int 默认值0
     * @return TableMediaBuilder
     */
    public TableMediaBuilder ySequenceFontSize(int ySequenceFontSize) {
        this.ySequenceFontSize = ySequenceFontSize;
        return this;
    }

    /**
     * 行序列字体
     * 颜色。 同表格背景颜色
     *
     * @param ySequenceFontColor 默认值1
     * @return TableMediaBuilder
     */
    public TableMediaBuilder ySequenceFontColor(String ySequenceFontColor) {
        this.ySequenceFontColor = ySequenceFontColor;
        return this;
    }

    /**
     * 行序列字体风格
     *
     * @param ySequenceFontStyle int
     *                           0-常规
     *                           1-加粗
     *                           2-倾斜
     *                           4-下划线
     *                           8-中划线
     *                           字体风格可以
     *                           组合，例如 3
     *                           表示加粗且倾
     *                           斜显示。
     * @return TableMediaBuilder
     */
    public TableMediaBuilder ySequenceFontStyle(int ySequenceFontStyle) {
        this.ySequenceFontStyle = ySequenceFontStyle;
        return this;
    }

    /**
     *
     * @param isShowXSequence  是否显示列序列
     * @return TableMediaBuilder
     */
    public TableMediaBuilder isShowXSequence(boolean isShowXSequence) {
        this.isShowXSequence = isShowXSequence;
        return this;
    }

    /**
     *
     * @param xSequenceDateArray 列序列。
     * @return TableMediaBuilder
     */
    public TableMediaBuilder xSequenceDateArray(String[] xSequenceDateArray) {
        this.xSequenceDateArray = xSequenceDateArray;
        return this;
    }

    /**
     * 列序列字体。
     *
     * @param xSequenceFontName 同行序列字体
     * @return TableMediaBuilder
     */
    public TableMediaBuilder xSequenceFontName(String xSequenceFontName) {
        this.xSequenceFontName = xSequenceFontName;
        return this;
    }

    /**
     * 列序列字体
     * 大小。
     *
     * @param xSequenceFontSize 默认值0
     * @return TableMediaBuilder
     */
    public TableMediaBuilder xSequenceFontSize(int xSequenceFontSize) {
        this.xSequenceFontSize = xSequenceFontSize;
        return this;
    }

    /**
     * 行序列字体
     * 颜色。
     *
     * @param xSequenceFontColor 同表格背景颜
     *                           色。
     * @return TableMediaBuilder
     */
    public TableMediaBuilder xSequenceFontColor(String xSequenceFontColor) {
        this.xSequenceFontColor = xSequenceFontColor;
        return this;

    }

    /**
     * 列序列字体
     * 风格。
     *
     * @param xSequenceFontStyle 同行序列字体
     *                           风格。
     * @return TableMediaBuilder
     */
    public TableMediaBuilder xSequenceFontStyle(int xSequenceFontStyle) {
        this.xSequenceFontStyle = xSequenceFontStyle;
        return this;
    }

    /**
     * 序列线粗。
     *
     * @param sequenceGridWidth int
     * @return TableMediaBuilder
     */
    public TableMediaBuilder sequenceGridWidth(int sequenceGridWidth) {
        this.sequenceGridWidth = sequenceGridWidth;
        return this;
    }

    /**
     * 序列线颜色。
     *
     * @param sequenceGridColor 同表格背景颜色
     * @return TableMediaBuilder
     */
    public TableMediaBuilder sequenceGridColor(String sequenceGridColor) {
        this.sequenceGridColor = sequenceGridColor;
        return this;
    }

    /**
     * @param horizontalPadding 单元格水平内边距
     * @return TableMediaBuilder
     */
    public TableMediaBuilder horizontalPadding(int horizontalPadding) {
        this.horizontalPadding = horizontalPadding;
        return this;
    }

    /**
     * @param verticalPadding 单元格垂直
     * @return TableMediaBuilder
     */
    public TableMediaBuilder verticalPadding(int verticalPadding) {
        this.verticalPadding = verticalPadding;
        return this;
    }

    /**
     * 动画参数
     *
     * @param animationType 特效 1 时，表
     *                      示每次滚动像
     *                      素；特效 2 时，
     *                      表示每次翻动
     *                      的高度
     * @return TableMediaBuilder
     */
    public TableMediaBuilder animationType(String animationType) {
        this.animationType = animationType;
        return this;
    }

    /**
     * 动画参数。
     *
     * @param animationValue 特效 1 时，表
     *                       示每次滚动像
     *                       素；特效 2 时，
     *                       表示每次翻动
     *                       的高度
     * @return TableMediaBuilder
     */
    public TableMediaBuilder animationValue(String animationValue) {
        this.animationValue = animationValue;
        return this;
    }

    /**
     * 动画时长。
     *
     * @param animationWaitValue 特效 1 时，最
     *                           上方和下放停
     *                           留时间，单位
     *                           毫秒；特效 2
     *                           时，表示每页
     *                           停留时间，单
     *                           位毫秒
     * @return TableMediaBuilder
     */
    public TableMediaBuilder animationWaitValue(String animationWaitValue) {
        this.animationWaitValue = animationWaitValue;
        return this;
    }

    /**
     * @param backgroundColorX 按行单元格
     *                         背景色
     * @return TableMediaBuilder
     */
    public TableMediaBuilder backgroundColorX(String[] backgroundColorX) {
        this.backgroudColorX = backgroundColorX;
        return this;
    }

    /**
     * @param colorY 按行单元格前景色
     * @return TableMediaBuilder
     */
    public TableMediaBuilder colorY(String[] colorY) {
        this.colorY = colorY;
        return this;
    }

    /**
     * @param backgroundColorY 按列单元格
     *                         背景色
     * @return TableMediaBuilder
     */
    public TableMediaBuilder backgroundColorY(String[] backgroundColorY) {
        this.backgroudColorY = backgroundColorY;
        return this;
    }

    /**
     * @param colorX 按列单元格前景色
     * @return TableMediaBuilder
     */
    public TableMediaBuilder colorX(String[] colorX) {
        this.colorX = colorX;
        return this;
    }

    /**
     * @param yTableHeightArray 行高
     * @return TableMediaBuilder
     */
    public TableMediaBuilder yTableHeightArray(int[] yTableHeightArray) {
        this.yTableHightArray = yTableHeightArray;
        return this;
    }

    /**
     * @param xTableWidthArray 列宽
     * @return TableMediaBuilder
     */
    public TableMediaBuilder xTableWidthArray(int[] xTableWidthArray) {
        this.xTableWidthArray = xTableWidthArray;
        return this;
    }

    /**
     * 内容部分字 同行序列字体
     * 体
     *
     * @param contentFontName 内容部分字 同行序列字体
     *                        体
     * @return TableMediaBuilder
     */
    public TableMediaBuilder contentFontName(int contentFontName) {
        this.contentFontName = contentFontName;
        return this;
    }

    /**
     * 内容部分字
     * 体大小
     *
     * @param contentFontSize 内容部分字
     *                        体大小
     * @return TableMediaBuilder
     */
    public TableMediaBuilder contentFontSize(int contentFontSize) {
        this.contentFontSize = contentFontSize;
        return this;
    }

    /**
     * 内容部分字
     * 体颜色。
     *
     * @param contentFontColor 同表格背景颜
     *                         色
     * @return TableMediaBuilder
     */
    public TableMediaBuilder contentFontColor(String contentFontColor) {
        this.contentFontColor = contentFontColor;
        return this;
    }

    /**
     * 内容部分字
     * 体风格。
     *
     * @param contentFontStyle 内容部分字
     *                         体风格。
     * @return TableMediaBuilder
     */
    public TableMediaBuilder contentFontStyle(int contentFontStyle) {
        this.contentFontStyle = contentFontStyle;
        return this;
    }

    /**
     * 内容部分线
     * 粗。
     *
     * @param contentGridWidth int
     * @return TableMediaBuilder
     */
    public TableMediaBuilder contentGridWidth(int contentGridWidth) {
        this.contentGridWidth = contentGridWidth;
        return this;
    }

    /**
     * 内容部分线
     * 条颜色
     *
     * @param contentGridColor 同表格背景颜
     *                         色
     * @return TableMediaBuilder
     */
    public TableMediaBuilder contentGridColor(String contentGridColor) {
        this.contentGridColor = contentGridColor;
        return this;
    }

    /**
     * 按行单元格
     * 水平布局。
     *
     * @param yTableAlignArray 0-居左
     *                         1-居右
     *                         2-居中
     * @return TableMediaBuilder
     */
    public TableMediaBuilder yTableAlignArray(int[] yTableAlignArray) {
        this.yTableAlignArray = yTableAlignArray;
        return this;
    }

    /**
     * 按列单元格
     * 水平布局
     *
     * @param xTableAlignArray 同上
     * @return TableMediaBuilder
     */
    public TableMediaBuilder xTableAlignArray(int[] xTableAlignArray) {
        this.xTableAlignArray = xTableAlignArray;
        return this;
    }

    /**
     * 自定义数据
     * 内容。
     *
     * @param yxDate2DArray 自定义数据
     *                      内容。
     * @return TableMediaBuilder
     */
    public TableMediaBuilder yxDate2DArray(String[][] yxDate2DArray) {
        this.yxDate2DArray = yxDate2DArray;
        return this;
    }

    /**
     * 合 并 单 元
     * 格，单元格
     * 起始和结束
     * 行列下标，
     * 从 0 开始
     *
     * @param userCellRange int[][]
     *                      每个合并区域
     *                      为一个长度为
     *                      4 的数组，格
     *                      式为：[[起始
     *                      行,结束行,起
     *                      始 列 , 结 束
     *                      列],[],[]]
     * @return TableMediaBuilder
     */
    public TableMediaBuilder userCellRange(int[][] userCellRange) {
        this.userCellRange = userCellRange;
        return this;
    }

    /**
     * 显 示 Excel
     * 名字
     *
     * @param excelName ExcelName
     * @return TableMediaBuilder
     */
    public TableMediaBuilder excelName(String excelName) {
        this.excelName = excelName;
        return this;
    }

    /**
     * 显 示 Excel
     * 第几个
     * sheet
     *
     * @param excelSheetIndex 第几个
     * @return TableMediaBuilder
     */
    public TableMediaBuilder excelSheetIndex(int excelSheetIndex) {
        this.excelSheetIndex = excelSheetIndex;
        return this;
    }

    /**
     * String
     * 取 值 sql 、
     * mysql、oracle
     *
     * @param dbType mysql、oracle
     * @return TableMediaBuilder
     */
    public TableMediaBuilder dbType(String dbType) {
        this.dbType = dbType;
        return this;
    }

    /**
     * 数据库服务
     * 器地址。
     *
     * @param ip ip
     * @return TableMediaBuilder
     */
    public TableMediaBuilder ip(String ip) {
        this.ip = ip;
        return this;
    }

    /**
     * @param port 数据库服务
     *             器端口。
     * @return TableMediaBuilder
     */
    public TableMediaBuilder port(int port) {
        this.port = port;
        return this;
    }

    /**
     * 数 据 库 名
     * 称。
     *
     * @param dbTable 数 据 库 名称。
     * @return TableMediaBuilder
     */
    public TableMediaBuilder dbTable(String dbTable) {
        this.dbTable = dbTable;
        return this;
    }

    /**
     * @param user 用户名。
     * @return TableMediaBuilder
     */
    public TableMediaBuilder user(String user) {
        this.user = user;
        return this;
    }

    /**
     * @param password 密码。。
     * @return TableMediaBuilder
     */
    public TableMediaBuilder password(String password) {
        this.password = password;
        return this;
    }

    /**
     * @param cycleTime 查询周期
     * @return TableMediaBuilder
     */
    public TableMediaBuilder cycleTime(int cycleTime) {
        this.cycleTime = cycleTime;
        return this;
    }

    /**
     * @param dbSql 查询sq
     * @return TableMediaBuilder
     */
    public TableMediaBuilder dbSql(String dbSql) {
        this.dbSql = dbSql;
        return this;
    }


}
