package nova.traffic.media;

public final class TextMediaBuilder extends BaseMediaBuild {
     String font = "1";
     int textSize = 1616;
     String textColor = "1", backGroundColor = "8";
     String text = "";
     String flash = "0";
     int fontStyle = 0;
     int wordSpace = 0;
     int alignmentDirection = 0;

    @Override
    public TextMediaBuilder x(int x) {
        return (TextMediaBuilder) super.x(x);
    }

    @Override
    public TextMediaBuilder y(int y) {
        return (TextMediaBuilder) super.y(y);
    }

    @Override
    public TextMediaBuilder width(int width) {
        return (TextMediaBuilder) super.width(width);
    }

    @Override
    public TextMediaBuilder height(int height) {
        return (TextMediaBuilder) super.height(height);
    }

    /**

     * 【1-黑体 2-楷体 3-宋体 4-仿宋 5-隶书
     * 可以使用字体名称，如 arial 等。】
     *
     * @param font 字体类型
     * @return TextMediaBuilder
     */
    public TextMediaBuilder font(String font) {
        this.font = font;
        return this;
    }


    /**
     * 字体大小，单位像素。由宽
     * 度和高度组成，宽高各占两
     * 个字符。如 0808、3232，
     * 999999，对应的字体大小
     * 是 8、32、999。
     *
     * @param textSize 默认值 1616
     * @return TextMediaBuilder
     */
    public TextMediaBuilder textSize(int textSize) {
        this.textSize = textSize;
        return this;
    }

    /**
     * 字符显示颜色
     *
     * @param textColor 1-红色
     *                  2-绿色
     *                  3-蓝色
     *                  4-黄色
     *                  5-紫色
     *                  6-青色
     *                  7-白色
     *                  8-黑色
     *                  可以使用 RGB 定义，
     *                  如 FF0000 表示红色
     * @return TextMediaBuilder
     */
    public TextMediaBuilder textColor(String textColor) {
        this.textColor = textColor;
        return this;
    }

    /**
     * 字符显示区域背景颜色。
     *
     * @param backGroundColor 1-红色
     *                        2-绿色
     *                        3-蓝色
     *                        4-黄色
     *                        5-紫色
     *                        6-青色
     *                        7-白色
     *                        8-黑色
     *                        可以使用 RGB 定义，
     *                        如 FF0000 表示红色
     * @return TextMediaBuilder
     */
    public TextMediaBuilder backGroundColor(String backGroundColor) {
        this.backGroundColor = backGroundColor;
        return this;
    }

    /**
     *
     *
     * @param text 显示的字符。
     * @return TextMediaBuilder
     */
    public TextMediaBuilder text(String text) {
        this.text = text;
        return this;
    }


    /**
     * 字体风格
     *
     * @param fontStyle 0-常规
     *                  1-加粗
     *                  2-倾斜
     *                  4-下划线
     *                  8-中划线
     *                  字体风格可以组合，例
     *                  如 3 表示加粗且倾斜
     *                  显示
     * @return TextMediaBuilder
     */
    public TextMediaBuilder fontStyle(int fontStyle) {
        this.fontStyle = fontStyle;
        return this;
    }

    /**
     *
     *
     * @param wordSpace  字符间隔大小，单位像素 0-1000
     * @return TextMediaBuilder
     */
    public TextMediaBuilder wordSpace(int wordSpace) {
        this.wordSpace = wordSpace;
        return this;
    }

    /**
     * 字符排列方向。
     *
     * @param alignmentDirection 横向排列 0
     *                           纵向排列 1
     * @return TextMediaBuilder
     */
    public TextMediaBuilder alignmentDirection(int alignmentDirection) {
        this.alignmentDirection = alignmentDirection;
        return this;
    }

    @Override
    public BaseMedia build() {
        return new TextMedia(this);
    }
}
