package nova.traffic.media;

public final class TextPlusBuilder extends BaseMediaBuild {
    String font = "1";
    int textSize = 1616, fontStyle = 0;
    String alignmentH = "0", alignmentV = "0";
    String lineSpace = "1";
    int wordSpace = 0;
    String textColor = "1", backGroundColor = "8";
    String effect = "0", speed = "2";
    int playCount = 1;
    String text = "";
    int isPlayTextVoice = 0, synchronizePlay = 0;
    int voiceSound = 0;
    int volume = 5;
    int voiceSpeed = 5;
    int intonation = 5;


    @Override
    public TextPlusBuilder x(int x) {
        return (TextPlusBuilder) super.x(x);
    }

    @Override
    public TextPlusBuilder y(int y) {
        return (TextPlusBuilder) super.y(y);
    }

    @Override
    public TextPlusBuilder width(int width) {
        return (TextPlusBuilder) super.width(width);
    }

    @Override
    public TextPlusBuilder height(int height) {
        return (TextPlusBuilder) super.height(height);
    }

    /**
     * 【1-黑体 2-楷体 3-宋体 4-仿宋 5-隶书
     * 可以使用字体名称，如 arial 等。】
     *
     * @param font 字体类型
     * @return TextPlusBuilder
     */
    public TextPlusBuilder font(String font) {
        this.font = font;
        return this;
    }

    /**
     * 字体大小，单位像素。由宽度和高度组成，宽高各占两个字符。如 0808、3232，999999，对应的字体是 8、32、999。
     *
     * @param textSize 默认值 1616
     * @return TextPlusBuilder
     */
    public TextPlusBuilder textSize(int textSize) {
        this.textSize = textSize;
        return this;
    }

    /**
     * 0-常规
     * 1-加粗
     * 2-倾斜
     * 4-下划线
     * 8-中划线
     * 字体风格可以组合，
     * 例如 3 表示加粗且倾
     * 斜显示。
     *
     * @param fontStyle 字体风格
     * @return TextPlusBuilder
     */
    public TextPlusBuilder fontStyle(int fontStyle) {
        this.fontStyle = fontStyle;
        return this;
    }

    /**
     * 文本内容水平对齐方式
     *
     * @param alignmentH * 0-左对齐
     *                   1-右对齐
     *                   2-居中
     * @return TextPlusBuilder
     */
    public TextPlusBuilder alignmentH(String alignmentH) {
        this.alignmentH = alignmentH;
        return this;
    }

    /**
     * 文本内容垂直对齐方式。
     *
     * @param alignmentV * 0-上对齐
     *                   1-下对齐
     *                   2-居中
     * @return TextPlusBuilder
     */
    public TextPlusBuilder alignmentV(String alignmentV) {
        this.alignmentV = alignmentV;
        return this;
    }

    /**
     * @param lineSpace 行间距，单位像素。0-100
     * @return TextPlusBuilder
     */
    public TextPlusBuilder lineSpace(String lineSpace) {
        this.lineSpace = lineSpace;
        return this;
    }

    /**
     * @param wordSpace 字符间距，单位像素。0-100
     * @return TextPlusBuilder
     */
    public TextPlusBuilder wordSpace(int wordSpace) {
        this.wordSpace = wordSpace;
        return this;
    }

    /**
     * 1-红色
     * 2-绿色
     * 3-蓝色
     * 4-黄色
     * 5-紫色
     * 6-青色
     * 7-白色
     * 8-黑色
     * 可以使用 RGB 定义，
     *
     * @param textColor 字符显示颜色。
     * @return TextPlusBuilder
     */
    public TextPlusBuilder textColor(String textColor) {
        this.textColor = textColor;
        return this;
    }

    /**
     * 字符显示区域背景颜色 同字符设置
     *
     * @param backGroundColor 默认值8
     * @return TextPlusBuilder
     */
    public TextPlusBuilder backGroundColor(String backGroundColor) {
        this.backGroundColor = backGroundColor;
        return this;
    }

    /**
     * 播放特效类型。 默认值0
     *
     * @param effect 0-无特效
     *               1-立即显示
     *               2-上展
     *               3-下展
     *               4-左展
     *               5-右展
     *               6-上移
     *               7-下移
     *               8-左移
     *               9-右移
     *               10-淡入淡出
     *               255-随机
     *               12-从右往左滚动
     *               13-从左往右桂东
     *               14-从下往上滚动
     *               15-从上往下滚动
     * @return TextPlusBuilder
     */
    public TextPlusBuilder effect(String effect) {
        this.effect = effect;
        return this;
    }

    /**
     * 0-最慢
     * 1-较慢
     * 2-常速
     * 3-较快
     * 4-最快
     *
     * @param speed 特效速度 默认值2
     * @return TextPlusBuilder
     */
    public TextPlusBuilder speed(String speed) {
        this.speed = speed;
        return this;
    }

    /**
     * @param playCount 播放次数 默认1
     * @return TextPlusBuilder
     */
    public TextPlusBuilder playCount(int playCount) {
        this.playCount = playCount;
        return this;
    }

    /**
     * @param text 显示的字符。
     * @return TextPlusBuilder
     */
    public TextPlusBuilder text(String text) {
        this.text = text;
        return this;
    }

    /**
     * 是否语音播报文字内容。
     *
     * @param isPlayTextVoice 0-不播报
     *                        1-播报
     * @return TextPlusBuilder
     */
    public TextPlusBuilder isPlayTextVoice(int isPlayTextVoice) {
        this.isPlayTextVoice = isPlayTextVoice;
        return this;
    }

    /**
     * 是否同步播放 语音播报与文字显示是否
     * 同步。
     *
     * @param synchronizePlay 0-不同步
     *                        1-同步
     * @return TextPlusBuilder
     */
    public TextPlusBuilder synchronizePlay(int synchronizePlay) {
        this.synchronizePlay = synchronizePlay;
        return this;
    }

    /**
     * 设置发声音人
     *
     * @param voiceSound 0-普通女声
     *                   1-普通男声
     *                   2-特别男声
     * @return TextPlusBuilder
     */
    public TextPlusBuilder voiceSound(int voiceSound) {
        this.voiceSound = voiceSound;
        return this;
    }

    /**
     * @param volume 音量  文字合成语音的音量。 0-9
     * @return TextPlusBuilder
     */
    public TextPlusBuilder volume(int volume) {
        this.volume = volume;
        return this;
    }

    /**
     * 语速
     *
     * @param voiceSpeed 文字合成语音的速度。 0-9
     * @return TextPlusBuilder
     */
    public TextPlusBuilder voiceSpeed(int voiceSpeed) {
        this.voiceSpeed = voiceSpeed;
        return this;
    }

    /**
     * @param intonation 音调 文字合成语音的音调。 0-9
     * @return TextPlusBuilder
     */
    public TextPlusBuilder intonation(int intonation) {
        this.intonation = intonation;
        return this;
    }

    @Override
    public BaseMedia build() {
        return new TextPlusMedia(this);
    }
}
