package nova.traffic.media.manage;

import com.google.gson.Gson;
import nova.traffic.media.*;
import nova.traffic.media.DClockMediaBuild;
import nova.traffic.media.PlayBuilder;
import nova.traffic.media.help.MediaAllStrategyImpl;
import nova.traffic.utils.NovaTraffic;
import nova.traffic.utils.NovaTrafficImp;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 * 媒体的播放类，局部更新，item实时更新，标准协议播放
 */
public class PlayTest {


    public static void main(String[] args) {

//        NovaTraffic novaTraffic = new NovaTraffic("192.168.0.220", 5000);
        NovaTraffic novaTraffic = new NovaTraffic("172.18.175.10", 5000);
//        sendTableMedia(novaTraffic);
//        LogUtil.log(getPlayContext());
//        sendRoadPlay(novaTraffic);
        sendRegionUpdate(novaTraffic);
    }


    /**
     * 生成一个节目播放内容
     *
     * @return
     */
    public static String getPlayContext() {

        TextMediaBuilder mediaBuilder = new TextMediaBuilder();
        mediaBuilder
                .x(0)
                .y(0)
                .width(16)
                .height(16)
                .textColor("1")
                .backGroundColor("8")
                .text("哈")
                .wordSpace(0)
                .alignmentDirection(1) //字符排列方向
                .font("2")
                .textSize(12);

        PlayBuilder playBuilder = new PlayBuilder().Id(1)  //设置id
                .addBuilderItem(new ItemMediaBuilder().duration(20).addBuilderMedia(mediaBuilder)) //添加页面
                .mediaStrategyImp(new MediaAllStrategyImpl());//设置策略（普通节目，局部更新，实时更新）
        String protocol = playBuilder.builder().createProtocol();

        return protocol;

    }


    /**
     * 局部更新 regionUpdate
     */
    public static int sendRegionUpdate(NovaTrafficImp novaTraffic) {
        //创建一个item build（页面）
        ItemMediaBuilder itemBuild1 = new ItemMediaBuilder();
        ItemMediaBuilder itemBuild2 = new ItemMediaBuilder();
        ItemMediaBuilder itemBuild3 = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        //创建一个image的build对象
        ImageMediaBuilder imageBuild1 = new ImageMediaBuilder();
        ImageMediaBuilder imageBuild2 = new ImageMediaBuilder();
        //通过build构建image媒体参数
        imageBuild1
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\2.jpg")
                .x(10)
                .y(10)
                .width(50)
                .height(100);
        imageBuild2
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\1.jpg")
                .x(10)
                .y(10)
                .width(50)
                .height(100);

        VideoMediaBuilder videoBuild = new VideoMediaBuilder();
        videoBuild
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\video.mp4")
                .x(10)
                .y(150)
                .width(50)
                .height(100);

        GifMediaBuilder gifBuild = new GifMediaBuilder();
        gifBuild
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\3.gif")
                .x(10)
                .y(150)
                .width(50)
                .height(100);

        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild
                .Id(1)
                .addBuilderItem(itemBuild1
                        .duration(20)
                        .addBuilderMedia(imageBuild1)
                        .addBuilderMedia(imageBuild2))
                .addBuilderItem(itemBuild2
                        .addBuilderMedia(videoBuild)
                        .duration(20))
                .addBuilderItem(itemBuild3
                        .addBuilderMedia(gifBuild)
                        .duration(10));
        //局部更新
        return playManage.regionUpdate();

    }


    /**
     * item实时更新 regionUpdate
     */
    public static int sendLiveUpdating(NovaTrafficImp novaTraffic) {
        //创建一个item build（页面）
        ItemMediaBuilder itemBuild1 = new ItemMediaBuilder();

        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        //创建一个image的build对象
        ImageMediaBuilder imageBuild1 = new ImageMediaBuilder();
        ImageMediaBuilder imageBuild2 = new ImageMediaBuilder();
        //通过build构建image媒体参数
        imageBuild1
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\2.jpg")
                .x(10)
                .y(10)
                .width(50)
                .height(50);
        imageBuild2
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\1.jpg")
                .x(10)
                .y(150)
                .width(50)
                .height(50);


        playBuild.Id(2)
                .addBuilderItem(itemBuild1
                        .duration(20)
                        .addBuilderMedia(imageBuild1)
                        .addBuilderMedia(imageBuild2)
                        .itemIndex(1)/*实时更新需要单独设置该参数*/);


        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        //实时更新
        return playManage.liveUpdating();

    }

    /**
     * 标准播放 play
     */
    public static int sendMulMedia(NovaTrafficImp novaTraffic) {
        //创建一个item build（页面）
        ItemMediaBuilder itemBuild1 = new ItemMediaBuilder();
        ItemMediaBuilder itemBuild2 = new ItemMediaBuilder();
        ItemMediaBuilder itemBuild3 = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        //创建一个image的build对象
        ImageMediaBuilder imageBuild1 = new ImageMediaBuilder();
        ImageMediaBuilder imageBuild2 = new ImageMediaBuilder();
        //通过build构建image媒体参数
        imageBuild1
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\2.jpg")
                .x(10)
                .y(10)
                .width(100)
                .height(100);
        imageBuild2
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\1.jpg")
                .x(10)
                .y(150)
                .width(100)
                .height(100);

        VideoMediaBuilder videoBuild = new VideoMediaBuilder();
        videoBuild
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\video.mp4")
                .x(10)
                .y(150)
                .width(100)
                .height(100);

        GifMediaBuilder gifBuild = new GifMediaBuilder();
        gifBuild
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\3.gif")
                .x(10)
                .y(150)
                .width(100)
                .height(100);
        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(10)
                .addBuilderItem(itemBuild1
                        .duration(20)
                        .addBuilderMedia(imageBuild1)
                        .addBuilderMedia(imageBuild2))
                .addBuilderItem(itemBuild2
                        .addBuilderMedia(videoBuild)
                        .duration(20))
                .addBuilderItem(itemBuild3
                        .addBuilderMedia(gifBuild)
                        .duration(10));
        return playManage.play();

    }


    /**
     * 发送图片[多图片]
     */
    public static int sendImageMedia(NovaTrafficImp novaTraffic) {

        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        //创建一个image的build对象
        ImageMediaBuilder mediaBuilder1 = new ImageMediaBuilder();
        ImageMediaBuilder mediaBuilder2 = new ImageMediaBuilder();
        //通过build构建image媒体参数
        mediaBuilder1
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\2.jpg")
                .x(10)
                .y(10)
                .width(100)
                .height(100);
        mediaBuilder2
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\1.jpg")
                .x(10)
                .y(150)
                .width(100)
                .height(100);

        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(1)
                .addBuilderItem(itemBuild
                        .addBuilderMedia(mediaBuilder1)
                        .addBuilderMedia(mediaBuilder2));
        return playManage.play();
    }

    /**
     * 发送图片
     */
    public static int sendImageMedia(NovaTrafficImp novaTraffic, String filePath) {

        if (!new File(filePath).exists()) {
            return -1;
        }
        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        //创建一个image的build对象
        ImageMediaBuilder mediaBuilder = new ImageMediaBuilder();
        //通过build构建image媒体参数
        mediaBuilder
                .filePath(filePath);

        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(1)
                .addBuilderItem(itemBuild
                        .addBuilderMedia(mediaBuilder));
        return playManage.play();
    }


    /**
     * 发送视频
     */
    public static int sendVideoMedia(NovaTrafficImp novaTraffic) {

        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        //创建一个image的build对象
        VideoMediaBuilder mediaBuilder = new VideoMediaBuilder();
        //通过build构建image媒体参数
        mediaBuilder
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\video.mp4")
                .x(10)
                .y(150)
                .width(100)
                .height(100);

        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild
                .Id(2)
                .addBuilderItem(itemBuild
                        .addBuilderMedia(mediaBuilder));
        return playManage.play();
    }

    /**
     * 发送gif
     */
    public static int sendGifMedia(NovaTrafficImp novaTraffic) {

        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        GifMediaBuilder mediaBuilder = new GifMediaBuilder();
        mediaBuilder
                .filePath("C:\\Users\\Nova004157\\Pictures\\image\\3.gif")
                .x(10)
                .y(150)
                .width(100)
                .height(100);

        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(3).addBuilderItem(itemBuild.addBuilderMedia(mediaBuilder));
        return playManage.play();
    }

    /**
     * 发送web
     */
    public static int sendWebMedia(NovaTrafficImp novaTraffic) {

        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        WebMediaBuilder mediaBuilder = new WebMediaBuilder();
        mediaBuilder
                .url("https://baike.baidu.com/item/%E9%81%8D%E5%8E%86/9796023?fr=aladdin")
                .x(10)
                .y(10)
                .width(200)
                .height(200);

        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(4).addBuilderItem(itemBuild.addBuilderMedia(mediaBuilder));
        return playManage.play();
    }


    /**
     * 普通文本【详细创建参数说明】
     */
    public static int sendTextMedia(NovaTrafficImp novaTraffic) {

        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        TextMediaBuilder mediaBuilder = new TextMediaBuilder();
        mediaBuilder
                .x(10)
                .y(10)
                .width(200)
                .height(200)
                .textColor("4")
                .backGroundColor("2")
                .text("普通文本")
                .wordSpace(30)
                .alignmentDirection(1) //字符排列方向
                .font("2")
                .textSize(30);

        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(5).addBuilderItem(itemBuild.addBuilderMedia(mediaBuilder));
//        return playManage.play();
        return playManage.regionUpdate();
    }

    /**
     * 普通文本【详细创建参数说明】
     */
    public static int sendTextMedia(NovaTrafficImp novaTraffic, String text) {
        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();
        TextMediaBuilder mediaBuilder = new TextMediaBuilder();
        mediaBuilder.text(text);
        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(5).addBuilderItem(itemBuild.addBuilderMedia(mediaBuilder));
        return playManage.play();
    }

    /**
     * 扩展文本媒体
     */
    public static int sendTextPlusMedia(NovaTrafficImp novaTraffic) {
        String text = "扩展文本媒体";
        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        TextPlusBuilder mediaBuilder = new TextPlusBuilder();
        /**
         * 基础播放
         */
//        mediaBuilder.text(text).alignmentV("2").alignmentH("2");
        //完全自定义播放内容
        mediaBuilder
                .x(0)
                .y(0)
                .width(0)
                .height(0)
                .textColor("4") //文字颜色
                .backGroundColor("2") //背景颜色
                .text(text) //文字显示
                .wordSpace(10) //文字间距
                .font("2") //字体类型
                .fontStyle(8) //
                .textSize(30) //文字大小
                .alignmentH("1")
                .alignmentV("1") //对齐方式
                .effect("12") //特效
                .speed("4"); //特效速度

        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(6).addBuilderItem(itemBuild.duration(1000).addBuilderMedia(mediaBuilder));
        return playManage.play();
    }

    /**
     * 时钟媒体
     */
    public static int sendDClickMedia(NovaTrafficImp novaTraffic) {

        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();
        DClockMediaBuild mediaBuilder = new DClockMediaBuild();
        mediaBuilder
                .x(10)
                .y(10)
                .width(200) //宽
                .height(200) //高
                .textColor("4") // 文字颜色
                .backGroundColor("2") //背景颜色
                .singleLine("1") //是否单行显示
                .wordSpace(10) //文字间距
                .font("2") // 字体类型
                .fontStyle(4) //文字风格
                .textSize(12) //文字大小
                .alignmentH("1") //对齐方式 h
                .alignmentV("1") //对齐方式 v
                .dateFormat("$yyyy/$MM/$dd_n_$HH:$mm:$ss $E $N") //自定义日期显示
                .setCharWeek("0|1|2|3|4|5|6"); //自定义星期显示

        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(7).addBuilderItem(itemBuild.addBuilderMedia(mediaBuilder));
        return playManage.play();
    }


    /**
     * 表格媒体
     */
    public static int sendTableMedia(NovaTrafficImp novaTraffic) {
        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        TableMediaBuilder mediaBuilder = new TableMediaBuilder();
        mediaBuilder
                .x(10)
                .y(10)
                .width(0)
                .height(0)
                .yxDate2DArray(new String[][]{{"1", "4"}, {"3", "4"}, {"3", "4"}, {"3", "4"}, {"3", "4"}}) //设置表格数据
                //只能同时显示一种效果，每个表格背景格子的颜色
                /*.backgroundColorX(new String[]{"2","3"})*/.backgroundColorY(new String[]{"2", "3", "4", "5", "6"}) //设置表格数据的背景颜色
                .isShowXSequence(true)  //显示表格的x序列号
                .xSequenceDateArray(new String[]{"1", "2", "3", "4", "5"}) //自定义序列号
                .isShowYSequence(true)  //显示表格的y序列号
                .horizontalPadding(10) //文字表格间距(h)
                .verticalPadding(15)  // 文字表格间距(v)
                .useDB(false); //默认不使用数据库，如果使用数据库需要将该处设置为true，并且添加上数据的服务器、数据表等信息

        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(8).addBuilderItem(itemBuild.addBuilderMedia(mediaBuilder));
        return playManage.play();
    }

    /**
     * 路网图底图发送
     *
     * @param novaTraffic NovaTraffic
     */
    public static void sendRoadPlay(NovaTraffic novaTraffic) {
        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        //表格
        RoadMediaBuilder roadMediaBuilder = new RoadMediaBuilder();

        roadMediaBuilder
                .x(12)
                .y(15)
                .width(300)
                .height(300)//105
                .backgroundColor("8")
                .addBaseRoute(new BaseRoute.BaseRouteBuild().Id(1).name("成华大道").color("1").width(4).addPoint(20, 20).addPoint(40, 40).addPoint(300, 300).build())
                .addBaseRoute(new BaseRoute.BaseRouteBuild().Id(2).name("建设路").color("2").width(4).addPoint(30, 40).addPoint(60, 80).addPoint(100, 120).build())
                .addBaseRoute(new BaseRoute.BaseRouteBuild().Id(3).name("西部大道").color("3").width(4).addPoint(20, 90).addPoint(150, 150).addPoint(200, 400).build())
                .build();
//        playBuild.Id(1).addBuilderItem(itemBuild.addBuilderMedia(roadMediaBuilder).duration(100));
//        String protocol = playBuild.builder().createProtocol();
//        LogUtil.log("" + protocol);
        PlayManager playManage = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(2).addBuilderItem(itemBuild.addBuilderMedia(roadMediaBuilder));
        playManage.play();
    }

    /**
     * 发送拥堵路段信息
     *
     * @param novaTraffic
     */
    public static void sendTJRoadPlay(NovaTraffic novaTraffic) {
        List<TJRoute> list = new ArrayList<>();
        TJRoute tjRoute1 = new TJRoute.TJRouteBuild().Id(1).color("1").startPercent(0.1f).endPercent(0.6f).usePercent().build();
        TJRoute tjRoute2 = new TJRoute.TJRouteBuild().Id(2).color("1").startPercent(0.1f).endPercent(0.1f).usePercent().build();
        TJRoute tjRoute3 = new TJRoute.TJRouteBuild().Id(3).color("7").startPercent(0.3f).endPercent(0.6f).usePercent().build();
        TJRoute tjRoute5= new TJRoute.TJRouteBuild().Id(0).color("FFF000").startPercent(0.7f).endPercent(0.85f).usePercent().build();
        list.add(tjRoute1);
        list.add(tjRoute2);
        list.add(tjRoute3);
        list.add(tjRoute5);
        novaTraffic.updateTJRoad(list);
    }


}
