package nova.traffic.server;

import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.nio.channels.SelectableChannel;
import java.nio.channels.SelectionKey;
import java.nio.channels.Selector;
import java.nio.channels.SocketChannel;
import java.util.Iterator;
import java.util.Set;

public class ClientChannel extends Channel{
	private volatile boolean isClose = false;
	private Selector selector;
	public synchronized boolean open(){
		try {
			selector = Selector.open();
			isClose = false;
			new Thread(new Runnable() {
				@Override
				public void run() {
					while (!isClose) {
						try {
							Set<SelectionKey> tK = selector.keys();
							if(tK==null||tK.isEmpty()) {
								continue;
							}
							selector.select();
							Set<SelectionKey> keys = selector.selectedKeys();
							Iterator<SelectionKey> iter = keys.iterator();
							while(iter.hasNext()) {
								SelectionKey key = iter.next();
								if(key.isConnectable()) {
									onConnected(key.channel());
								}//连接成功&正常
								else  if(key.isReadable()) {//可读
									onReadable(key.channel());
								}else  if(key.isWritable()) {//可读
									onWritable(key.channel());
								}
								iter.remove();
							}
						} catch (IOException e) {
							e.printStackTrace();
						}
					}
				}
			}).start();
		} catch (IOException e1) {
			e1.printStackTrace();
			return false;
		}
		return true;
	}
	/**
	 * 添加一个客户端
	 * @param ip
	 * @param port
	 * @return
	 */
	SocketChannel addClient(String ip,int port) {
		SocketChannel channel = null;
		try {
			if(selector == null) {
				return null;
			}
			synchronized (selector) {
				channel = SocketChannel.open();
				channel.configureBlocking(false);
				channel.register(selector,SelectionKey.OP_CONNECT|SelectionKey.OP_READ|SelectionKey.OP_WRITE);
				channel.connect(new InetSocketAddress(ip,port));
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		return channel;
	}

	public void close() {
		isClose = true;
		if(selector != null) {
			synchronized (selector) {
				try {
					selector.close();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}
	}

	private void onConnected(SelectableChannel channel) {
		String ip = null;
		int port = 0;
		try {
			SocketChannel socketChannel = (SocketChannel) channel;
			socketChannel.socket().setKeepAlive(true);
			InetAddress address = socketChannel.socket().getInetAddress();
			ip = address.getHostAddress();
			port = socketChannel.socket().getPort();
			if(socketChannel.finishConnect()) {
				notifyConnect(ip,port);
			}
		} catch (IOException e) {
			e.printStackTrace();
			onReadError(ip,port);
		}

	}

}
