package nova.traffic.server;

import nova.traffic.server.MessageParser.MessageParserCallback;
import nova.traffic.utils.LogUtil;
import nova.traffic.utils.NovaUtils;

import java.nio.channels.SocketChannel;
import java.nio.charset.StandardCharsets;
import java.util.UUID;

public abstract class MessageChannel{
	protected String ip;
	protected int port;
	private Channel mChannel;
	protected MessageParser messageParser;
	/**
	 * des加密key
	 */
	private String encodeKey;

	private int encodeType;
	/**
	 * 通道唯一id
	 */
	private String channelId;

	private long lastHeartbeatTime = -1;
	private MessageParserCallback callback = new MessageParserCallback(){
		@Override
		public void onReceive(byte[] bytes) {
			if(bytes==null) {
				return;
			}
			lastHeartbeatTime = System.currentTimeMillis();
			short exWhat=bytes[0];
			if(bytes[0] == NovaUtils.WHAT_HEART_BEAT ) {
				if(bytes.length>1) {
					onReceiveName(new String(bytes,1,bytes.length-1,StandardCharsets.UTF_8));
				}
				onHeartBeat();
				return;
			}else if(bytes[0]==NovaUtils.WHAT_EXPAND_PARAM_MARK&&bytes.length>=3){
				 exWhat = NovaUtils.bytesToShort(bytes, 1);
			}
			onReceiveBuffer(exWhat,bytes);
		}

		@Override
		public void onConnect() {
			// TODO Auto-generated method stub
			onHeartBeat();
		}

		@Override
		public void onReadMessageError() {
			MessageChannel.this.onDisconnect();

		}
	};

	public MessageChannel(String ip,int port) {
		this.ip = ip;
		this.port = port;
		channelId = UUID.randomUUID().toString();
		LogUtil.log("新链接channelId:"+channelId);
	}

	/**
	 * 通道id，每连接一台设备都会生成一个新的id
	 * @return
	 */
	public String getChannelId() {
		return channelId;
	}

	public int getEncodeType(){
		return encodeType;
	}

	public String getEncodeKey() {
		return encodeKey;
	}

	public void setEncodeKey(int encodeType, String encodeKey) {
		this.encodeKey = encodeKey;
		if(messageParser != null) {
			messageParser.setEncodeSecret(encodeType, encodeKey);
		}
	}

	public synchronized void send(byte[] bytes) throws Exception {
		if(mChannel !=null ) {
			mChannel.send(ip,port,bytes);
		}else {
			throw new Exception("服务端通道未绑定");
		}
	}


	public synchronized boolean listen(Channel serverChannel) {
		if(this.mChannel != null) {
			return false;
		}
		if(ip !=null && serverChannel != null) {
			if(serverChannel instanceof ClientChannel) {
				SocketChannel channel =  ((ClientChannel)serverChannel).addClient(ip, port);
				if(channel==null) {
					return false;
				}
				return true;
			}
			this.mChannel = serverChannel;
			messageParser = new MessageParser();
			messageParser.setCallback(callback);
			mChannel.putMessageParser(ip,port,messageParser);
		}
		return true;
	}

	public void close() {
		if(mChannel != null && ip != null) {
			mChannel.remove(ip,port);
			mChannel = null;
		}
	}


	/**
	 * 收到数据
	 * @param what 指令码
	 * @param bytes 数据域
	 */
	protected abstract void onReceiveBuffer(short what, byte[] bytes);
	/**
	 * 收到设备名称
	 * @param deviceName  deviceName
	 */
	protected abstract void onReceiveName(String deviceName);

	/**
	 * 心跳
	 */
	protected abstract void onHeartBeat();


	protected abstract void onDisconnect();
	/**
	 * 最后一次心跳时间
	 * @return 心跳时间
	 */
	public long getLastHeartbeatTime() {
		return lastHeartbeatTime;
	}
}
