package nova.traffic.task;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import nova.traffic.been.UploadFileParam;
import nova.traffic.server.NovaDevice;
import nova.traffic.utils.NovaUtils;

import java.io.IOException;
import java.net.UnknownHostException;
import java.nio.charset.StandardCharsets;
import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class FileUploadHttpTask extends NovaTask{
    private List<UploadFileParam> files;
    private int resultCode;
    private ProgressCallback callback;
    private ExecutorService executors;
    private volatile boolean isRelease = false;
    public FileUploadHttpTask(NovaDevice channel, List<UploadFileParam> files) {
        super(channel);
        this.files=files;
        executors =  Executors.newSingleThreadExecutor();
    }


    public ProgressCallback getCallback() {
        return callback;
    }


    public void setCallback(ProgressCallback callback) {
        this.callback = callback;
    }



    @Override
    public int execute() {
        try {
            byte[] tempbuf = getBytes(new Gson().toJson(files));
            byte[] outbuf = makeSendPacket(NovaUtils.WHAT_UPLOAD_FILES_BY_HTTP, tempbuf, tempbuf.length);
            write(outbuf);
            channel.receiveAsync(NovaUtils.WHAT_UPLOAD_FILES_BY_HTTP, new NovaDevice.Callback() {
                @Override
                public boolean onReceive(byte[] recvBuf) {
                    // TODO Auto-generated method stub
                    if (recvBuf == null||recvBuf.length<2) {
                        resultCode = NovaUtils.SEND_NOT_RECV_ERROR;
                        return false;
                    } else {
                        byte[] proByte = new byte[recvBuf.length - 2];
                        System.arraycopy(recvBuf, 2, proByte, 0, proByte.length);
                        String proStr = new String(proByte, StandardCharsets.UTF_8);
                        callbackProgress(proStr);
                        switch (recvBuf[1]) {
                            case SUCCESS:
                                resultCode = SUCCESS;
                                return false;
                            case ERROR:
                                resultCode = NovaUtils.SEND_RECV_ERROR;
                                return false;
                            case 2://下载中
                                return true;
                            default:
                                resultCode = NovaUtils.SEND_RECV_ERROR;
                                return false;
                        }
                    }
                }
            });
            return resultCode;
        } catch (UnknownHostException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
            return NovaUtils.UNKNOWN_HOST;
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
            return NovaUtils.IO_ERROR;
        }
    }


    private void callbackProgress(String str) {
        if(callback == null) {
            return;
        }
        executors.execute(new Runnable() {
            @SuppressWarnings("unchecked")
            @Override
            public void run() {
                try {
                    ProgressBean bean = null;
                    if(str!=null && !str.isEmpty()) {
                        bean = new Gson().fromJson(str, new TypeToken<ProgressBean>() {}.getType());
                    }
                    if(isRelease) {
                        return;
                    }
                    if(callback != null) {
                        callback.onProgress(bean);
                    }
                }catch (Exception e) {
                    e.printStackTrace();
                }

            }
        });
    }




    @Override
    public void release() {
        isRelease = true;
        if(executors!=null) {
            if(!executors.isShutdown()) {
                executors.shutdownNow();
            }
            executors = null;
        }
    }
}
