package nova.traffic.task;

import nova.traffic.server.NovaDevice;
import nova.traffic.utils.NovaUtils;

import java.io.IOException;
import java.io.UnsupportedEncodingException;

public abstract class NovaTask {
    protected NovaDevice channel;
    protected static final int SUCCESS = 1;
    protected static final int ERROR = 0;
    protected static final int TEMP_SIZE = 4096;
    protected static final int BIG_SIZE = 65535;
    public NovaTask(NovaDevice channel) {
        this.channel=channel;
    }
    public abstract int execute();
    public abstract void release();
    protected byte[] getBytes(String str) throws UnsupportedEncodingException {
        return str.getBytes("utf-8");
    }
    /**
     * 用于发送加密
     * @param what
     * @param data
     * @param dataSize
     * @return
     */
    protected byte[] makeSendPacket(byte what, byte[] data, int dataSize) {
        int encodeType = channel.getEncodeType();
        String encodeKey = channel.getEncodeKey();
        if (encodeKey != null && what != NovaUtils.WHAT_SECRET_DES_MD5_REQ) {
            return NovaUtils.makeSendPacket(what, data, dataSize, encodeType, encodeKey.getBytes());
        } else {
            return NovaUtils.makeSendPacket(what, data, dataSize);
        }
    }

    protected synchronized void write(byte[] outbuf) throws IOException {
        try {
            channel.send(outbuf);
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
            throw new IOException("写文件异常");
        }
    }
}
