package nova.traffic.test;

import nova.traffic.media.DClockMediaBuild;
import nova.traffic.media.ItemMediaBuilder;
import nova.traffic.media.PlayBuilder;
import nova.traffic.media.TextPlusBuilder;
import nova.traffic.media.help.MediaPartStrategyImpl;
import nova.traffic.media.manage.PlayManager;
import nova.traffic.server.NovaDevice;
import nova.traffic.server.ServerChannel;
import nova.traffic.utils.LogUtil;
import nova.traffic.utils.NovaTrafficImp;
import nova.traffic.utils.NovaTrafficServer;

import java.util.List;
import java.util.concurrent.*;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.stream.Collectors;

import static java.util.concurrent.TimeUnit.SECONDS;

/**
 * 多设备连接处理【模拟停车导航】
 */
public class NovaMulDevice {

    private ServerChannel channel;

    //创建定时线程，负责定时发送节目和局部更新
    private ScheduledThreadPoolExecutor scheduled = new ScheduledThreadPoolExecutor(3);
    private ExecutorService executorService = new ThreadPoolExecutor(10, 50, 100, TimeUnit.SECONDS, new ArrayBlockingQueue<>(50), Executors.defaultThreadFactory(), new ThreadPoolExecutor.DiscardOldestPolicy());
    /**
     * 获取当前区域
     *
     * @return
     */
    private int curRegion = 2;
    private boolean aBoolean = true;

    private NovaMulDevice(ServerChannel channel) {
        this.channel = channel;
    }

    private static NovaMulDevice instance = null;

    public synchronized static NovaMulDevice getInstance(ServerChannel channel) {
        if (instance == null) {
            instance = new NovaMulDevice(channel);

        }
        return instance;
    }


    /**
     * 启动定时任务，每分钟刷新一次线程
     * 1.查询当前车辆数
     * 2.更新导航牌标语
     */
    public void start() {
        scheduled.scheduleAtFixedRate(playRun, 60L, 60 * 20L, SECONDS);
        scheduled.scheduleAtFixedRate(sendRun, 10L, 2L, SECONDS);  //局部更新
        scheduled.scheduleAtFixedRate(timerRun, 30L, 60 * 20L, SECONDS);
    }

    public void addDeviceToPlay(NovaDevice client) {
        new Thread(() -> {
            try {
                Thread.sleep(10000L);
            } catch (Exception e) {
                LogUtil.log("addDeviceToPlay:" + e.toString());
                Thread.currentThread().interrupt();
            }
            NovaTrafficServer novaTraffic = client.obtainTrafficServer();
            if (aBoolean) {
                sendMulMedia1(novaTraffic);
            } else
                sendMulMedia2(novaTraffic);
        }).start();


    }


    private Runnable sendRun = this::sendRegionShow;


    private Runnable playRun = () -> {
        aBoolean = !aBoolean;
        sendPlayShow();
    };
    private Runnable timerRun = this::sendPlayShow;


    public String getCurRegion() {
        if (curRegion == 1) {
            curRegion = 2;
            return "地下车库-B区";
        } else {
            curRegion = 1;
            return "地下车库-A区";
        }
    }

    int num = 0;

    /**
     * 局部更新信息
     */
    private void sendRegionShow() {
//        1. A区，B区切换;
//        2. 区域切换，伴随着车位数变化
        List<NovaDevice> allDevices = channel.getAllDevices(); //拿到所有设备
        if (num < 999) {
            num++;
        } else {
            num = 1;
        }

        PlayBuilder playBuild = sendRegionUpdate(getCurRegion(), num);
//        LogUtil.log("当前局部更新指令：" + playBuild.mediaStrategyImp(new MediaPartStrategyImpl()).builder().createProtocol());
        AtomicBoolean isEnable = new AtomicBoolean(true);
        allDevices.forEach(client -> {
            if (client.enable()) {
                executorService.execute(() -> {
                    NovaTrafficServer novaTraffic = client.obtainTrafficServer();
                    PlayManager playManager = new PlayManager(playBuild, novaTraffic);
                    playManager.regionUpdate();
                });
            } else {
                isEnable.set(false);
                LogUtil.logInfo("设备离线：离线设备信息：" + client.toString());
            }
        });
        if (!isEnable.get()) {
            int size = (int) allDevices.stream().filter(NovaDevice::enable).count();
            LogUtil.logInfo("----当前设备总数:" + allDevices.size() + " 当前设备在线数：" + size);
        }
    }

    /**
     * play播放切换
     */
    private void sendPlayShow() {
   /*    1. A区，B区切换;
       2. 区域切换，伴随着车位数变化*/
        List<NovaDevice> allDevices = channel.getAllDevices(); //拿到所有设备
        allDevices.forEach(client -> {
            if (client.enable()) {
                NovaTrafficServer novaTraffic = client.obtainTrafficServer();
                if (aBoolean) {
                    sendMulMedia1(novaTraffic);
                } else {
                    sendMulMedia2(novaTraffic);
                }
            }

        });
    }

    /**
     * 标准播放 play
     */
    public int sendMulMedia1(NovaTrafficImp novaTraffic) {
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();

        TextPlusBuilder textBuild = new TextPlusBuilder();
        DClockMediaBuild dClickMedia = new DClockMediaBuild();
        dClickMedia.x(50).y(30).width(200).height(150).dateFormat("$yyyy/$MM/$dd_n_$HH:$mm:$ss $E");
        textBuild
                .x(50)
                .y(200)
                .width(200)
                .height(80)
                .text("剩余车位数")
                .textSize(22);


        PlayManager playManager = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(1)
                .addBuilderItem(itemBuild
                        .duration(100)
                        .addBuilderMedia(dClickMedia)
                        .addBuilderMedia(textBuild));
        return playManager.play();
    }

    /**
     * 标准播放 play
     */
    public int sendMulMedia2(NovaTrafficImp novaTraffic) {
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        //创建一个item build（页面）
        ItemMediaBuilder itemBuild = new ItemMediaBuilder();

        TextPlusBuilder textBuild = new TextPlusBuilder();
        DClockMediaBuild dClickMedia = new DClockMediaBuild();
        dClickMedia.x(30).y(40).width(200).height(80).dateFormat("$yyyy/$MM/$dd_n_$HH:$mm:$ss $E").singleLine("0").alignmentH("0");
        textBuild
                .x(50)
                .y(200)
                .width(200)
                .height(80)
                .text("剩余车位数")
                .textSize(22);


        PlayManager playManager = new PlayManager(playBuild, novaTraffic);
        playBuild.Id(2)
                .addBuilderItem(itemBuild
                        .duration(100)
                        .addBuilderMedia(dClickMedia)
                        .addBuilderMedia(textBuild));
        return playManager.play();
    }


    /**
     * 局部更新 regionUpdate
     */
    public static PlayBuilder sendRegionUpdate(String text, int carNum) {
        //创建一个item build（页面）
        ItemMediaBuilder itemBuild1 = new ItemMediaBuilder();
        //创建一个playBuild（节目）
        PlayBuilder playBuild = new PlayBuilder();

        //创建一个image的build对象
        TextPlusBuilder textMediaBuild = new TextPlusBuilder();
        TextPlusBuilder textMediaBuildNum = new TextPlusBuilder();
        //通过build构建image媒体参数
        textMediaBuild
                .x(250)
                .y(30)
                .width(170)
                .height(80)
                .text("地下车库-A区")
                .textSize(22)
                .text(text);

        textMediaBuildNum.x(0).y(0).text(carNum + "").textSize(20).width(64).height(32);
        playBuild
                .Id(1)
                .addBuilderItem(itemBuild1
                        .duration(20)
                        .addBuilderMedia(textMediaBuild)
                        .addBuilderMedia(textMediaBuildNum));
        //局部更新
        return playBuild;

    }


}
