package nova.traffic.test;

import nova.traffic.server.NovaDevice;
import nova.traffic.server.ServerChannel;
import nova.traffic.utils.LogConfig;
import nova.traffic.utils.LogUtil;
import nova.traffic.utils.NovaTrafficServer;

import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.Scanner;

public class ServerTest {

    public static void main(String[] args) throws UnknownHostException {
        start();
    }

    public static void start() throws UnknownHostException {
        LogConfig.debug = true;
        LogConfig.logFileDir = "F:\\JavaSdkLog";
//LogConfig.logFilePath="F:\\JavaSdkLog\\nova.log";
        InetAddress localHost = InetAddress.getLocalHost();
        String serverIp = localHost.getHostAddress(); //服务端ip
        int serverPort = 5000;               //服务端端口号
        ServerChannel serverChannel = new ServerChannel();
        serverChannel.setClientConnectListener(new NovaDevice.ConnectListener() {
            @Override
            public void onDisconnect(NovaDevice client, String ip) {
                LogUtil.log("客户端" + ip + "离线或者心跳超时，设备名称："+client.getDeviceName());

            }

            @Override
            public void onConnected(NovaDevice client, String ip) {
                String deviceName = client.getDeviceName();
                LogUtil.log(deviceName + "连接成功");
//				test(client);

                new  Thread(new Runnable() {
                    @Override
                    public void run() {
                        NovaTrafficServer novaTraffic = client.obtainTrafficServer();
                        String sn = novaTraffic.getSN();
                        LogUtil.log("SN:"+sn);
                    }
                });

            }

            @Override
            public void onReceivedHeartBeat(NovaDevice channel, String ip) {
                LogUtil.log("收到设备心跳："+channel.getDeviceName());

            }
        });
        boolean b = serverChannel.open(serverIp, serverPort);
        if (b) {
            LogUtil.log("服务端通道已开启");
            //开启心跳检查线程
            serverChannel.startCheckHeartbeat(40);

        } else {
            LogUtil.log("服务端通道开启失败");
            return;
        }

        while (true) {
            LogUtil.log("请输入功能编号进行测试：");
            try {
                int what = new Scanner(System.in).nextInt();
//                NovaDevice client = serverChannel.getDeviceByIp("Taurus-30000190");
                NovaDevice client = serverChannel.getAllDevices().stream().findAny().orElse(null);
                if (client != null && client.enable()) {

                    NovaTrafficServer novaTraffic = client.obtainTrafficServer();
                    client.setTimeOut(10*1000);
//					novaTraffic.resetScreenTest();
//					novaTraffic.test((byte)0xB6);
//                    DeviceNowPlayList nowPlayAllContent = novaTraffic.getNowPlayAllContent();
//                    LogUtil.log(nowPlayAllContent.getContent());
//                    DeviceNowPlayItem nowPlayContent = novaTraffic.getNowPlayContent();
//                    LogUtil.log(nowPlayContent.getContent());
                    NovaTrafficTest.excute(novaTraffic, what);
                } else {
                    LogUtil.log("客户端未连接");
                }
            } catch (Exception e) {
                LogUtil.log("e:"+e.toString());
                break;
            }

        }
    }

    private static void test(final NovaDevice channel) {
        new Thread(new Runnable() {

            @Override
            public void run() {
                long count = 0;
                NovaTrafficServer novaTraffic = channel.obtainTrafficServer();
                LogUtil.log("开始测试");
                while (true) {
                    if (!channel.enable()) {
                        LogUtil.log("客户端关闭，停止测试");
                        return;
                    }
                    count = System.currentTimeMillis();
                    String content = "[all]\r\n" +
                            "items=1\r\n" +
                            "[item-1]\r\n" +
                            "param=100,1,1,1,0,5,1,0,1\r\n" +
                            "txt1=0,100,3,3636,1,8,0," + count + ",0,0,0\r\n" +
                            "txtparam1=0,0";

                    int ret = novaTraffic.sendLocalUpdate(1, content);
                    if (ret != 1) {
                        System.out.print(count + " 失败  " + ret);
                    }
                    try {
                        Thread.sleep(10);
                    } catch (Exception e) {
                       LogUtil.log(e.toString());
                       break;
                    }
                }

            }
        }).start();
    }

}
